@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-VERSION = '0.4.2'
+VERSION = '0.4.3'
 
 import os
 import sys
@@ -17,7 +17,10 @@ import string
 import random
 import time
 
-width = shutil.get_terminal_size((20, 0)).columns
+try:
+    width = shutil.get_terminal_size((40, 0)).columns
+except AttributeError:
+    width = 40
 
 
 def get_args():
